@@ -13,6 +13,7 @@ describe 'sahara::db' do
         :max_retries    => '<SERVICE DEFAULT>',
         :retry_interval => '<SERVICE DEFAULT>',
         :max_overflow   => '<SERVICE DEFAULT>',
+        :pool_timeout   => '<SERVICE DEFAULT>',
       )}
     end
 
@@ -26,6 +27,7 @@ describe 'sahara::db' do
           :database_retry_interval => '11',
           :database_max_pool_size  => '11',
           :database_max_overflow   => '21',
+          :database_pool_timeout   => '21',
         }
       end
 
@@ -38,6 +40,7 @@ describe 'sahara::db' do
         :max_retries    => '11',
         :retry_interval => '11',
         :max_overflow   => '21',
+        :pool_timeout   => '21',
       )}
     end
 
@@ -67,7 +70,7 @@ describe 'sahara::db' do
         { :database_connection => 'sqlite://sahara:sahara@localhost/sahara', }
       end
 
-      it_raises 'a Puppet::Error', /validate_re/
+      it { should raise_error(Puppet::Error, /validate_re/) }
     end
 
     context 'with incorrect database_connection string' do
@@ -75,7 +78,7 @@ describe 'sahara::db' do
         { :database_connection => 'foo+pymysql://sahara:sahara@localhost/sahara', }
       end
 
-      it_raises 'a Puppet::Error', /validate_re/
+      it { should raise_error(Puppet::Error, /validate_re/) }
     end
   end
 
